@@ -1,7 +1,6 @@
 # Process autolinks '<protocol:...>'
 import re
-from .state_inline import StateBase
-from ..common.utils import charCodeAt
+from .state_inline import StateInline
 from ..common.normalize_url import normalizeLinkText, normalizeLink, validateLink
 
 EMAIL_RE = re.compile(
@@ -10,11 +9,11 @@ EMAIL_RE = re.compile(
 AUTOLINK_RE = re.compile(r"^<([a-zA-Z][a-zA-Z0-9+.\-]{1,31}):([^<>\x00-\x20]*)>")
 
 
-def autolink(state: StateBase, silent: bool):
+def autolink(state: StateInline, silent: bool):
 
     pos = state.pos
 
-    if charCodeAt(state.src, pos) != 0x3C:  # /* < */
+    if state.srcCharCode[pos] != 0x3C:  # /* < */
         return False
 
     tail = state.src[pos:]
